@@ -1,9 +1,9 @@
 <?php
 
 // -----------------------------------------------------------------------
-// This file is part of aroundme
+// This file is part of AROUNDMe
 //
-// Copyright (C) 2003, 2005 Barnraiser
+// Copyright (C) 2003 - 2006 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -19,18 +19,10 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with program; see the file COPYING. If not, write to the Free
-// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 // -----------------------------------------------------------------------
 
-
-require_once($languagePath . 'sn_common.lang.php');
-/*
-* All language vars should be ordered TYPE, A-Z for convenience
-* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
-*/
-
-
 //HEADER
 $lang['hdr_blocked'] = 							"blocked";
 
@@ -42,10 +34,4 @@ $lang['err_no_blocked'] = 						"You are not blocking anyone.";
 //HREF
 $lang['href_unblock'] = 						"unblock this person";
 
-
-//SUBMIT BUTTONS
-//$lang['sub_save'] = 							"save";
-//BODY TEXT
-//$lang['txt_nic'] =								"nickname (nic)";
-
 ?>
