@@ -52,6 +52,7 @@ $schedule->rsp_level_id = $rsp_level_id;
 
 
 // SETUP LANGUAGE --------------------------------------------------------
+require_once($languagePath . 'common.lang.php');
 require_once($languageArrayPath . 'arr_schedule.lang.php');
 require_once($languageArrayPath . 'arr_user.lang.php');
 
@@ -59,7 +60,6 @@ require_once($languageArrayPath . 'arr_user.lang.php');
 //SETUP WIKI -------------------------------------------------------------
 require_once('class/Wiki/Wiki.php');
 $wiki = new Text_Wiki();
-$wiki->disableRule('wikilink');
 	
 	
 // SETUP COMMENTS --------------------------------------------------------
@@ -90,6 +90,10 @@ if (isset($me['user_id'])) {
 
 
 // SETUP FILTER ----------------------------------------------------------
+$schedule->start_date = $date->formatFormDateTime(date("Y-m-d")); //now
+
+/*
+these filters will be moved to the search engine in a later release - TC
 if(!empty($frmdata['start_date'])) { // default is today
 	$schedule->start_date = $date->formatFormDateTime($frmdata['start_date']);
 }
@@ -107,7 +111,7 @@ $schedule->status_ids = array($c_node['schedule']['status']['confirmed']);
 if(!empty($frmdata['schedule_status'])) {
 	array_push($schedule->status_ids, $c_node['schedule']['status']['tentative']);
 }
-	
+*/	
 
 // PROCESS FORM ----------------------------------------------------------
 if (isset($_REQUEST['view']) && $_REQUEST['view'] == "node") {
@@ -160,7 +164,7 @@ elseif (isset($_POST['insert'])) {
 			$statistic->group_id = $frmdata['group_id'];
 			
 			//update group stats
-			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id);
+			unset($comment->user_id, $statistic->user_id, $comment->rsp_item_type_id, $comment->item_id, $comment->item_user_id);
 			$statistic->statistic_type_id = $c_node['statistic']['group']['total_comments'];
 			$statistic->setStatistic($comment->getCommentCount());
 			
@@ -270,8 +274,8 @@ elseif (isset($_REQUEST['view'])) {
 			endforeach;
 		}
 		
-		$lang['txt_intro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
-		$lang['txt_outro_group'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
+		$lang['txt_intro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_group']);
+		$lang['txt_outro_group'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_group']);
 		
 		$output_my_group_schedule_items = $mygroups;
 		
@@ -316,8 +320,8 @@ elseif (isset($_REQUEST['view'])) {
 		
 		$output_my_network_schedule_items = $output_users;
 		
-		$lang['txt_intro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
-		$lang['txt_outro_network'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
+		$lang['txt_intro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_network']);
+		$lang['txt_outro_network'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_outro_network']);
 		
 		$menu_section = "network";
 	}
@@ -352,12 +356,80 @@ elseif (isset($_REQUEST['view'])) {
 		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['schedule'];
 		$watched_schedule_ids = $bookmark->getBookmarks();
 		
-		$schedule->user_id = $me['user_id'];
-		
 		if (!empty($watched_schedule_ids)) {
 			$schedule->schedule_ids = $watched_schedule_ids;
 			$output_schedule_items = $schedule->selScheduleItems();
 		}
+		
+		// remove schedule items authored by me
+		if (!empty($output_schedule_items)) {
+			foreach($output_schedule_items as $key => $i):
+			echo $i['user_id'] . " ";
+				if ($me['user_id'] == $i['user_id']) {
+					unset ($output_schedule_items[$key]);
+				}
+			endforeach;
+		}
+		
+		$lang['txt_intro'] = $lang['txt_intro_marked'];
+	}
+	elseif ($_REQUEST['view'] == "tipped_schedule_items" && isset($me['user_id'])) {
+		//get my relations tipped schedule items
+		unset($schedule->rsp_level_id);
+		$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
+		$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
+		$schedule->file = $file;
+		
+		unset($bookmark->user_id);
+		
+		$my_network = $_SESSION['relations'];
+		
+		if (!empty($my_network)) {
+			foreach($my_network as $key => $i):
+				$bookmark->user_ids[] = $i['user_id_relation'];
+				$user->user_ids[] = $i['user_id_relation'];
+			endforeach;
+		}
+		else {
+			$bookmark->user_ids[] = 0;
+			$user->user_ids[] = 0;
+		}
+		
+		$user->file = $file;
+		$output_users = $user->selUsers();
+		
+		
+		$bookmark->bookmark_type = $c_node['bookmark']['type']['recommend'];
+		$bookmark->rsp_item_type_id = $c_node['rsp']['item_type']['schedule'];
+		$recommended_schedule_ids = $bookmark->getBookmarks(1);
+		
+		if (!empty($recommended_schedule_ids)) {
+			foreach($recommended_schedule_ids as $key => $i):
+				$schedule->schedule_ids[] = $i['item_id'];
+			endforeach;
+			
+			$recommended_schedule_items = $schedule->selScheduleItems();
+			
+			//sort schedule items under people
+			if (!empty($output_users) && !empty($recommended_schedule_items)) {
+				foreach ($output_users as $item_key => $i): // for each user we get their tipped items
+					foreach($recommended_schedule_ids as $bookmark_key => $b):
+						if ($i['user_id'] == $b['user_id']) {
+							// we get the schedule
+							foreach($recommended_schedule_items as $content_key => $c):
+								if ($c['schedule_id'] == $b['item_id']) {
+									$output_users[$item_key]['schedule_items'][] = $c;
+									unset ($recommended_schedule_items[$content_key]);
+								}
+							endforeach;
+						}
+					endforeach;
+				endforeach;
+			}
+			
+		}
+		$output_recommended_schedule_items = $output_users;
+		$lang['txt_intro'] = $lang['txt_intro_tipped'];
 	}
 }
 elseif (isset($_REQUEST['user_id'])) {
@@ -387,7 +459,7 @@ elseif (isset($_REQUEST['user_id'])) {
 		$output_profile['image']['file'] = $file->noimage;
 	}
 }
-elseif (isset($_REQUEST['schedule_id'])) {
+elseif (!empty($_REQUEST['schedule_id'])) {
 	unset($schedule->rsp_level_id);
 	$schedule->schedule_id = $_REQUEST['schedule_id'];
 	
@@ -401,7 +473,6 @@ elseif (isset($_REQUEST['group_id'])) {
 	$schedule->file = $file;
 	
 	unset($menu_section);
-	
 	$output_schedule_items = $schedule->selScheduleItems();
 	
 }
@@ -415,7 +486,7 @@ else { // get the latest item published to node
 	
 	$output_schedule_items = $schedule->selScheduleItems();
 	
-	$lang['txt_intro_node'] = str_replace('MAXLISTNUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
+	$lang['txt_intro_node'] = str_replace('SYS_KEYWORD_NUMBER', $c_node['display']['max_list_rows'], $lang['txt_intro_node']);
 	
 	$menu_section = "magazine";
 	
@@ -432,22 +503,27 @@ if (!empty($output_schedule_item)) {
 	$rsp = new Rsp($db, $c_node['rsp']['item_type']['schedule']);
 	$output_schedule_item['rsp'] = $rsp->selRspItem($schedule->schedule_id);
 	
-	if (!empty($output_schedule_item['rsp'])) { // is the item set to public?
+	
+	if (isset($me['user_id']) && $me['user_id'] == $output_schedule_item['user_id']) {
+		// is the author me?
+		$allow_view = 1;
+	}
+	elseif (isset($rss_access_granted)) { // RSS Feed link
+		$allow_view = 1;
+	}
+	elseif (!empty($output_schedule_item['rsp'])) { // is the item set to public?
 		foreach ($output_schedule_item['rsp'] as $key => $i):
 			if ($i['level_id'] == $c_node['rsp']['rsp_level']['public']) {
 				$allow_view = 1;
 				break;
 			}
-			elseif (!empty($_SESSION['s_md5']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
+			elseif (!empty($_SESSION['s_md5']) && empty($i['degree_id']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
 				$allow_view = 1;
 				break;
 			}
-			elseif ($i['level_id'] == $c_node['rsp']['rsp_level']['degree'] && empty($i['degree_id'])) { // is it set to network (everyone)?
-				$allow_view = 1;
-			}
 			elseif (!empty($i['degree_id'])) { // is it set to network and are they in my network?
 				foreach($_SESSION['relations'] as $key => $r):
-					if ($output_schedule_item['user_id'] == $r['user_id_relation']) {
+					if ($output_blog['user_id'] == $r['user_id_relation']) {
 						$allow_view = 1;
 						break;
 					}
@@ -459,10 +535,6 @@ if (!empty($output_schedule_item)) {
 			}
 		endforeach;
 	}
-	elseif (isset($me['user_id']) && $me['user_id'] == $output_schedule_item['user_id']) {
-		// is the author me?
-		$allow_view = 1;
-	}
 	
 	if (!empty($output_schedule_item['group_id'])) {
 		require_once('class/Group.class.php');
@@ -511,9 +583,15 @@ if (!empty($output_schedule_item)) {
 if (isset($output_schedule_item['schedule_id'])) {
 	//wikify body
 	$wiki_path = "lib_view.php?page=";
-	$wiki_new_path = "lib_edit.php?page=";
 	$wiki_image_base = "get_file.php?file=";
 	
+	if (!empty($output_schedule_item['group_id'])) {
+		$wiki_new_path = "lib_edit.php?group_id=" . $output_schedule_item['group_id'] . "&page=";
+	}
+	else {
+		$wiki_new_path = "lib_edit.php?page=";
+	}
+	
 	$wiki->setRenderConf('xhtml', 'wikilink', 'view_url', $wiki_path);
 	$wiki->setRenderConf('xhtml', 'wikilink', 'new_url', $wiki_new_path);
 	$wiki->setRenderConf('xhtml', 'image', 'base', $c_node['dir']['asset_path'] . $wiki_image_base);
@@ -521,8 +599,12 @@ if (isset($output_schedule_item['schedule_id'])) {
 	
 	
 	// GET AUTHOR
-	if (!empty($output_blog['group_id'])) {
-		$output_author = $user->selProfile($output_group['member']['profile_id'], null);
+	if (!empty($output_schedule_item['group_id'])) {
+		$output_group['author'] = $group->getGroupMembership($output_schedule_item['user_id']);
+		
+		if (!empty($output_group['author']['profile_id'])) {
+			$output_author = $user->selProfile($output_group['author']['profile_id'], null);
+		}
 	}
 	else {
 		$output_author = $user->selProfile(null, $output_schedule_item['user_id']);
@@ -549,6 +631,10 @@ if (isset($output_schedule_item['schedule_id'])) {
 	}
 	
 	//get comments
+	if (isset($_SESSION['user_preferences']['comment_mode']) && $_SESSION['user_preferences']['comment_mode'] == "normal_mode") {
+		$comment->no_comment_parent_id = 1;
+	}
+	
 	unset($comment->user_id);
 	if (!empty($output_blog['group_id'])) {
 		$comment->group_id = $output_blog['group_id'];
@@ -578,10 +664,10 @@ if (!isset($output_schedule_item)) {
 	unset($schedule->user_id);
 	$schedule->schedule_type_id = $c_node['schedule']['type']['event'];
 	$total_schedule_items = $schedule->countScheduleItems();
-	$lang['txt_event_summary'] = str_replace('SCHEDTOTAL', $total_schedule_items, $lang['txt_event_summary']);
+	$lang['txt_event_summary'] = str_replace('SYS_KEYWORD_TOTAL', $total_schedule_items, $lang['txt_event_summary']);
 	$schedule->schedule_type_id = $c_node['schedule']['type']['task'];
 	$total_schedule_items = $schedule->countScheduleItems();
-	$lang['txt_task_summary'] = str_replace('SCHEDTOTAL', $total_schedule_items, $lang['txt_task_summary']);
+	$lang['txt_task_summary'] = str_replace('SYS_KEYWORD_TOTAL', $total_schedule_items, $lang['txt_task_summary']);
 }
 else {
 	unset($lang['txt_event_summary'], $lang['txt_task_summary']);
@@ -603,11 +689,13 @@ if (!empty($_REQUEST['view'])) {
 
 if (!empty($output_schedule_items)) {
    $body->set('schedule_items', $output_schedule_items);
+   unset($lang['nav_breadcrumb']);
 }
 
 if (!empty($output_schedule_item)) {
 	$body->set('schedule', $output_schedule_item);
-	$body->set('rsp_config', $c_node['rsp']); 
+	$body->set('rsp_config', $c_node['rsp']);
+	$lang['nav_breadcrumb_note'] = $output_schedule_item['schedule_title'];
 }
 
 if (!empty($output_author)) {
@@ -635,11 +723,22 @@ if (!empty($output_group)) {
 	$tpl->set('group', $output_group);
 }
 
+if (!empty($output_my_group_schedule_items)) {
+	$body->set('my_group_schedule_items', $output_my_group_schedule_items);
+}
+
+if (!empty($output_my_network_schedule_items)) {
+	$body->set('my_network_schedule_items', $output_my_network_schedule_items);
+}
+
+if (!empty($output_recommended_schedule_items)) {
+	$body->set('recommended_schedule_items', $output_recommended_schedule_items);
+}
+
 $body->set('schedule_config', $c_node['schedule']);
 $body->set('languagePath', $languagePath); //for calendar lang config
-$body->set('batch_enabled', $c_node['batch']['enabled']); 
-
-$template_pageLink = $lang['txt_schedule'];
+$body->set('batch_enabled', $c_node['batch']['enabled']);
+$body->set('rspconfig', $c_node['rsp']);
 
 include "inc/footer.inc.php";
 
